pub enum BoxContentsSource {
NONE,
FEED,
_2DBARCODE,
INTERACTIVE,
}Expand description
BoxContentsSource : Where the seller provided box contents information for a shipment. Where the seller provided box contents information for a shipment.
Variants
NONE
FEED
_2DBARCODE
INTERACTIVE